print("import: 'keyring'")
import keyring

print("import: 'keyring.backends'")
import keyring.backends

print("import: 'keyring.tests'")
import keyring.tests

print("import: 'keyring.tests.backends'")
import keyring.tests.backends

print("import: 'keyring.util'")
import keyring.util

